package cd.casic.ci.commons.commonapi.enums;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.ServiceLoader;
import java.util.concurrent.atomic.AtomicBoolean;

/**
 * 仅在初始化时调用一次，不可重复使用
 */
public class EnumLoader {
    private static final AtomicBoolean modify = new AtomicBoolean(false);
    private static final Logger logger = LoggerFactory.getLogger(EnumLoader.class);

    private EnumLoader() {
        // Private constructor to prevent instantiation
    }

    public static void enumModified() {
        // 同一JVM中防止多次重复加载，造成Enum实例不一致
        if (!modify.compareAndSet(false, true)) {
            return;
        }

        Class<EnumModifier> clazz = EnumModifier.class;
        ServiceLoader<EnumModifier> fetcheries = ServiceLoader.load(clazz);
        if (!fetcheries.iterator().hasNext()) {
            fetcheries = ServiceLoader.load(clazz, ServiceLoader.class.getClassLoader());
        }

        fetcheries.forEach(modifier -> {
            logger.info("[ENUM MODIFIER]: {}", modifier);
            try {
                modifier.modified();
            } catch (Exception e) {
                logger.error("[ENUM MODIFIER]| load fail| {}", e.getMessage(), e);
            }
        });
    }
} 