package cd.casic.ci.commons.commonapi.pojo;

import cd.casic.ci.commons.commonapi.enums.AgentStatus;
import com.fasterxml.jackson.annotation.JsonIgnore;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.AllArgsConstructor;
import lombok.Data;

@Data
@AllArgsConstructor
@Schema(title = "第三方Agent数据返回包装模型")
public class AgentResult<T> {
    @Schema(title = "状态码", required = true)
    private final Integer status;
    
    @Schema(title = "错误信息", required = false)
    private final String message;
    
    @Schema(title = "Agent状态", required = false)
    private final AgentStatus agentStatus;
    
    @Schema(title = "数据", required = false)
    private final T data;

    public AgentResult(AgentStatus status, T data) {
        this(0, null, status, data);
    }

    public AgentResult(Integer status, String message) {
        this(status, message, null, null);
    }

    @JsonIgnore
    public boolean isNotOk() {
        return status != 0;
    }

    @JsonIgnore
    public boolean isAgentNotOK() {
        return agentStatus == null || isAgentDelete();
    }

    @JsonIgnore
    public boolean isAgentDelete() {
        return agentStatus != null && agentStatus == AgentStatus.DELETE;
    }
} 